import direct.directbase.DirectStart
from direct.filter.CommonFilters import CommonFilters
from pandac.PandaModules import *
import fb
import meshgraph
from meshgraph import MeshGraph
from util import Clock
from direct.gui.DirectGui import *
import sys

filters = CommonFilters(base.win, base.cam)
render.setAttrib(LightRampAttrib.makeHdr1())
filters.setBloom(intensity = 1, size = 2)

# Set up fonts
textManager = TextPropertiesManager.getGlobalPtr()
boldProperties = TextProperties()
boldProperties.setFont(loader.loadFont("FontBold.ttf"))
textManager.setProperties("strong", boldProperties)
italicProperties = TextProperties()
italicProperties.setSlant(0.3)
textManager.setProperties("em", italicProperties)
subscriptProperties = TextProperties()
subscriptProperties.setGlyphScale(0.5)
subscriptProperties.setGlyphShift(-0.2)
textManager.setProperties("sub", subscriptProperties)
superscriptProperties = TextProperties()
superscriptProperties.setGlyphScale(0.5)
superscriptProperties.setGlyphShift(0.2)
textManager.setProperties("sup", superscriptProperties)
underlineProperties = TextProperties()
underlineProperties.setUnderscore(True)
textManager.setProperties("u", underlineProperties)

useCache = False

if base.appRunner:
	accessToken = base.appRunner.getToken("accessToken")
	if base.appRunner.getToken("demo") == "1":
		useCache = True
else:
	accessToken = sys.argv[1] if len(sys.argv) > 1 else ""

if useCache:
	graph = fb.CachedGraphAPI("cache.dat")
else:
	graph = fb.GraphAPI(accessToken)

skybox = loader.loadModel("skybox") 
skybox.setScale(2)
skybox.reparentTo(base.camera)
skybox.setBin("background", 0) 
skybox.setDepthWrite(0)
skybox.setP(90)
skybox.setLightOff()
skybox.setPos(0, 0, 0)
skybox.setCompass()

m = MeshGraph(graph)
me = m.constructNodes(None, 0, "Me", graph.request("me", "metadata=1"))
me.expanded = True

def back():
	m.goBack()

backButton = DirectButton(text = ("back", "back", "\1strong\1back\2", "back"), text_font = loader.loadFont("Font.ttf"), text_fg = Vec4(1, 1, 1, 1), clickSound = None, rolloverSound = None, relief = None, command = back)
backButton.setScale(0.04)
backButton.setPos(-1, 0, 0.95)

fog = Fog("Fog")
fog.setColor(1 / 255, 18 / 255, 44 / 255)
fog.setLinearRange(120, 200)
render.setFog(fog)

base.disableMouse()

clock = Clock()
meshgraph.clock = clock

def loop(task):
	clock.update()
	m.update(clock.timeStep)
	m.draw()
	return task.cont

taskMgr.add(loop, "Run loop")

run()